Page 73 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 73

Home

    regard to consequences. Results in demagogism, license,
    agitation, discontent, anarchy.”

    Because of a willingness to profit from the lessons of
    history, the Founding Fathers adopted a constitution that
    nowhere mentioned a democracy, as neither did the
    Declaration of Independence, nor a single constitution of

    our fifty states.

    What the Founding Fathers did choose to establish
    was a government of written and permanent law.
    Realizing that men can only remain free by limiting
    political power, these laws restricted the power of

    government.
    Rather than enumerate a long list of freedoms

    tea 1 a . 6

    guaranteed to the people, they enumerated a short list of
    what government could and could not do. Basically, this
    limited government to protecting life, liberty, and

    property.
    To guard against usurpation of power, they divided
    the power between three branches of the federal

    ww.

    government, the states, and the people. What the

    Founding Fathers gave us was a Constitutional Republic.
    One of the most important provisions of the

    Constitution was the establishment of a sound monetary

    system based upon gold and silver. This too had its roots
    in Old Testament Bible History. The first metal

    mentioned in Old Testament Scripture was gold, Genesis
    2:11. The location given was near Ancient Babylon,

    68

    The Secret Side of History

    The first metal